from .config import update_registry_from_config
from .geometry import Geometry, VerticalImage, NadirGeometry
from .atmosphere import Atmosphere

# Wrappers for core sasktranif objects
from .climatology import Climatology, ClimatologyUserDefined, ClimatologyUserDefined2D, ClimatologyUserDefined3D, Labow, Pratmo, MSIS90, ECMWF, GloSSAC
from .opticalproperty import OpticalProperty, MieAerosol, HITRANChemical, OpticalPropertyConvolved
from .opticalproperty import O3DBM, O3OSIRISRes, NO2Vandaele1998, Rayleigh, NO2OSIRISRes
from .engine import Engine, EngineHR, EngineDO
from .geodetic import Geodetic
from .solarspectrum import SolarSpectrum
from .brdf import BRDF, Lambertian, Roujean, Kokhanovsky, CoxMunk, Rahman, Hapke, MODIS
from .brdf import LinearCombination, RoujeanKernel, LiKernel, LiDenseKernel, LiSparseKernel, LiSparseReciprocalKernel
from .brdf import RossThinKernel, RossThickKernel
from .emission import Emission, EmissionTable, EmissionThermal

# Utility classes overtop of sasktranif objects
from .lineofsight import LineOfSight
from .species import Species, SpeciesAerosol, SpeciesAerosolGloSSAC
from .stokesvector import StokesVector

from .handles import standard_handles
from .exceptions import SasktranError
from ._version import get_versions
__version__ = get_versions()['version']
del get_versions


update_registry_from_config()
